@@ -11,10 +11,7 @@ test.run()
 #print("\nPackage at {0}".format( __path__[0]))
 
 import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 import os
 
 from ioflo import test
