@@ -5,10 +5,7 @@ Unit Test Template
 from __future__ import absolute_import, division, print_function
 
 import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 import os
 
