@@ -4,12 +4,8 @@ Unittests for nonblocking module
 """
 
 import sys
-if sys.version > '3':
-    xrange = range
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+
+import unittest
 
 import os
 import time
@@ -18,15 +14,9 @@ import shutil
 import socket
 import errno
 
-if sys.version > '3':
-    from http.client import HTTPConnection
-else:
-    from httplib import HTTPConnection
+from http.client import HTTPConnection
+from urllib.parse import urlsplit
 
-if sys.version > '3':
-    from urllib.parse import urlsplit
-else:
-    from urlparse import urlsplit
 
 try:
     import simplejson as json
@@ -169,7 +159,7 @@ class BasicTestCase(unittest.TestCase):
                                      method=method,
                                      path=path,
                                      headers=headers)
-        msgOut = request.build()
+        msgOut = request.rebuild()
         lines = [
                    b'GET /echo?name=fame HTTP/1.1',
                    b'Host: 127.0.0.1:8080',
@@ -257,7 +247,7 @@ class BasicTestCase(unittest.TestCase):
                                      method=method,
                                      path=path,
                                      headers=headers)
-        msgOut = request.build()
+        msgOut = request.rebuild()
         lines = [
                    b'GET /stream HTTP/1.1',
                    b'Host: 127.0.0.1:8080',
@@ -367,7 +357,7 @@ class BasicTestCase(unittest.TestCase):
                                      method=method,
                                      path=path,
                                      headers=headers)
-        msgOut = request.build()
+        msgOut = request.rebuild()
         lines = [
                    b'GET /fancy?idify=true;multiply=true HTTP/1.1',
                    b'Host: 127.0.0.1:8080',
@@ -471,7 +461,7 @@ class BasicTestCase(unittest.TestCase):
                                      method=method,
                                      path=path,
                                      headers=headers)
-        msgOut = request.build()
+        msgOut = request.rebuild()
         lines = [
                    b'GET /fancy?idify=true;jsonify=true HTTP/1.1',
                    b'Host: 127.0.0.1:8080',
@@ -581,7 +571,7 @@ class BasicTestCase(unittest.TestCase):
                                      headers=headers)
 
 
-        msgOut = request.build(fargs=fargs)
+        msgOut = request.rebuild(fargs=fargs)
 
         beta.tx(msgOut)
         while beta.txes or not beta.rxbs:
