@@ -159,7 +159,7 @@ class Act(object):
 
             #  compute .inode
             self.inode = (self.ioinits or odict()).get('inode', ioinits.get('inode', self.inode))
-            if self.inode is not None and not isinstance(self.inode, basestring):
+            if self.inode is not None and not isinstance(self.inode, (str, bytes)):
                 raise ValueError("Nonstring inode '{0}'".format(self.inode))
             if self.inode and not self.inode.endswith("."):  # ensure node not share path
                 self.inode = "{0}.".format(self.inode)
@@ -647,7 +647,8 @@ class Actor(object):
 
     def _initio(self, ioinits):
         """
-        Compute initializations for ioflo shares from ioinits odict or item list
+        Compute initializations for ioflo shares from ioinits (odict or item list)
+
         The 'inode' item in ioinits is special. Act.resolve extracts 'inode' from
         ioinits and assigns to ._act.inode before ._initio is called.
 
@@ -665,7 +666,7 @@ class Actor(object):
         The values of the items in the **kwa argument may be either strings or
         mappings
 
-        For each key,val in **kwa.items() there are the following 2 forms for val:
+        For each key,val in ioinits.items() there are the following 2 forms for val:
 
         1- string:
            ipath = pathnamestring
@@ -746,7 +747,7 @@ class Actor(object):
             if val is None:  # use default assume no way to be inadvertent
                 val = ""  # empty string for val defaults ipath to same as key
 
-            if isinstance(val, basestring):
+            if isinstance(val, (str, bytes)):
                 ipath = val
                 iown = None
                 ival = odict() # effectively will not change share
